@@ -26,7 +26,7 @@ from lean.models.brokerages.local import all_local_brokerages, local_brokerage_d
 from lean.models.brokerages.local.atreyu import AtreyuBrokerage
 from lean.models.brokerages.local.binance import BinanceBrokerage, BinanceDataFeed
 from lean.models.brokerages.local.bitfinex import BitfinexBrokerage, BitfinexDataFeed
-from lean.models.brokerages.local.bloomberg import BloombergBrokerage, BloombergDataFeed
+from lean.models.brokerages.local.terminal_link import TerminalLinkBrokerage, TerminalLinkDataFeed
 from lean.models.brokerages.local.coinbase_pro import CoinbaseProBrokerage, CoinbaseProDataFeed
 from lean.models.brokerages.local.interactive_brokers import InteractiveBrokersBrokerage, InteractiveBrokersDataFeed
 from lean.models.brokerages.local.iqfeed import IQFeedDataFeed
@@ -35,6 +35,9 @@ from lean.models.brokerages.local.paper_trading import PaperTradingBrokerage
 from lean.models.brokerages.local.tradier import TradierBrokerage, TradierDataFeed
 from lean.models.brokerages.local.trading_technologies import TradingTechnologiesBrokerage, TradingTechnologiesDataFeed
 from lean.models.brokerages.local.zerodha import ZerodhaBrokerage, ZerodhaDataFeed
+from lean.models.brokerages.local.samco import SamcoBrokerage, SamcoDataFeed
+from lean.models.brokerages.local.kraken import KrakenBrokerage, KrakenDataFeed
+from lean.models.brokerages.local.ftx import FTXBrokerage, FTXDataFeed
 from lean.models.errors import MoreInfoError
 from lean.models.logger import Option
 
@@ -48,6 +51,7 @@ _required_brokerage_properties = {
     "BitfinexBrokerage": ["bitfinex-api-secret", "bitfinex-api-key"],
     "BinanceBrokerage": ["binance-api-secret", "binance-api-key"],
     "ZerodhaBrokerage": ["zerodha-access-token", "zerodha-api-key", "zerodha-product-type", "zerodha-trading-segment"],
+    "SamcoBrokerage": ["samco-client-id", "samco-client-password", "samco-year-of-birth", "samco-product-type", "samco-trading-segment"],
     "BloombergBrokerage": ["job-organization-id", "bloomberg-api-type", "bloomberg-environment",
                            "bloomberg-server-host", "bloomberg-server-port", "bloomberg-emsx-broker"],
     "AtreyuBrokerage": ["job-organization-id", "atreyu-host", "atreyu-req-port", "atreyu-sub-port",
@@ -59,7 +63,9 @@ _required_brokerage_properties = {
                                      "tt-market-data-host", "tt-market-data-port",
                                      "tt-order-routing-sender-comp-id", "tt-order-routing-target-comp-id",
                                      "tt-order-routing-host", "tt-order-routing-port",
-                                     "tt-log-fix-messages"]
+                                     "tt-log-fix-messages"],
+    "KrakenBrokerage": ["kraken-api-key", "kraken-api-secret", "kraken-verification-tier"],
+    "FTXBrokerage": ["ftx-api-key", "ftx-api-secret", "ftx-account-tier", "ftx-exchange-name"]
 }
 
 # Data queue handler -> required configuration properties
@@ -72,9 +78,12 @@ _required_data_queue_handler_properties = {
     "BitfinexBrokerage": _required_brokerage_properties["BitfinexBrokerage"],
     "BinanceBrokerage": _required_brokerage_properties["BinanceBrokerage"],
     "ZerodhaBrokerage": _required_brokerage_properties["ZerodhaBrokerage"] + ["zerodha-history-subscription"],
+    "SamcoBrokerage": _required_brokerage_properties["SamcoBrokerage"],
     "BloombergBrokerage": _required_brokerage_properties["BloombergBrokerage"],
     "TradingTechnologiesBrokerage": _required_brokerage_properties["TradingTechnologiesBrokerage"],
-    "QuantConnect.ToolBox.IQFeed.IQFeedDataQueueHandler": ["iqfeed-iqconnect", "iqfeed-productName", "iqfeed-version"]
+    "QuantConnect.ToolBox.IQFeed.IQFeedDataQueueHandler": ["iqfeed-iqconnect", "iqfeed-productName", "iqfeed-version"],
+    "KrakenBrokerage": _required_brokerage_properties["KrakenBrokerage"],
+    "FTXBrokerage": _required_brokerage_properties["FTXBrokerage"]
 }
 
 _environment_skeleton = {
@@ -326,6 +335,10 @@ def _get_default_value(key: str) -> Optional[Any]:
               type=bool,
               default=lambda: _get_default_value("gdax-use-sandbox"),
               help="Whether the sandbox should be used")
+@click.option("--binance-organization",
+              type=str,
+              default=lambda: _get_default_value("job-organization-id"),
+              help="The name or id of the organization with the Binance module subscription")
 @click.option("--binance-api-key",
               type=str,
               default=lambda: _get_default_value("binance-api-key"),
@@ -338,6 +351,10 @@ def _get_default_value(key: str) -> Optional[Any]:
               type=bool,
               default=lambda: _get_default_value("binance-use-testnet"),
               help="Whether the testnet should be used")
+@click.option("--zerodha-organization",
+              type=str,
+              default=lambda: _get_default_value("job-organization-id"),
+              help="The name or id of the organization with the zerodha module subscription")
 @click.option("--zerodha-api-key",
               type=str,
               default=lambda: _get_default_value("zerodha-api-key"),
@@ -358,6 +375,30 @@ def _get_default_value(key: str) -> Optional[Any]:
               type=bool,
               default=lambda: _get_default_value("zerodha-history-subscription"),
               help="Whether you have a history API subscription for Zerodha")
+@click.option("--samco-organization",
+              type=str,
+              default=lambda: _get_default_value("job-organization-id"),
+              help="The name or id of the organization with the samco module subscription")
+@click.option("--samco-client-id",
+              type=str,
+              default=lambda: _get_default_value("samco-client-id"),
+              help="Your Samco account Client ID")
+@click.option("--samco-client-password",
+              type=str,
+              default=lambda: _get_default_value("samco-client-password"),
+              help="Your Samco account password")
+@click.option("--samco-year-of-birth",
+              type=str,
+              default=lambda: _get_default_value("samco-year-of-birth"),
+              help="Your year of birth (YYYY) registered with Samco")
+@click.option("--samco-product-type",
+              type=click.Choice(["MIS", "CNC", "NRML"], case_sensitive=False),
+              default=lambda: _get_default_value("samco-product-type"),
+              help="MIS if you are targeting intraday products, CNC if you are targeting delivery products, NRML if you are targeting carry forward products")
+@click.option("--samco-trading-segment",
+              type=click.Choice(["EQUITY", "COMMODITY"], case_sensitive=False),
+              default=lambda: _get_default_value("samco-trading-segment"),
+              help="EQUITY if you are trading equities on NSE or BSE, COMMODITY if you are trading commodities on MCX")
 @click.option("--iqfeed-iqconnect",
               type=PathParameter(exists=True, file_okay=True, dir_okay=False),
               default=lambda: _get_default_value("iqfeed-iqconnect"),
@@ -378,10 +419,10 @@ def _get_default_value(key: str) -> Optional[Any]:
               type=str,
               default=lambda: _get_default_value("iqfeed-version"),
               help="The product version of your IQFeed developer account")
-@click.option("--bloomberg-organization",
+@click.option("--terminal-link-organization",
               type=str,
               default=lambda: _get_default_value("job-organization-id"),
-              help="The name or id of the organization with the Bloomberg module subscription")
+              help="The name or id of the organization with the Terminal Link module subscription")
 @click.option("--bloomberg-environment",
               type=click.Choice(["Production", "Beta"], case_sensitive=False),
               default=lambda: _get_default_value("bloomberg-environment"),
@@ -526,6 +567,41 @@ def _get_default_value(key: str) -> Optional[Any]:
               type=bool,
               default=lambda: _get_default_value("tt-log-fix-messages"),
               help="Whether FIX messages should be logged")
+@click.option("--kraken-organization",
+              type=str,
+              default=lambda: _get_default_value("job-organization-id"),
+              help="The name or id of the organization with the kraken module subscription")
+@click.option("--kraken-api-key",
+              type=str,
+              default=lambda: _get_default_value("kraken-api-key"),
+              help="Your Kraken API key")
+@click.option("--kraken-api-secret",
+              type=str,
+              default=lambda: _get_default_value("kraken-api-secret"),
+              help="Your Kraken API secret")
+@click.option("--kraken-verification-tier",
+              type=str,
+              default=lambda: _get_default_value("kraken-verification-tier"),
+              help="Your Kraken Verification Tier")
+@click.option("--ftx-organization",
+              type=str,
+              default=lambda: _get_default_value("job-organization-id"),
+              help="The name or id of the organization with the FTX module subscription")
+@click.option("--ftx-api-key",
+              type=str,
+              default=lambda: _get_default_value("ftx-api-key"),
+              help="Your FTX API key")
+@click.option("--ftx-api-secret",
+              type=str,
+              default=lambda: _get_default_value("ftx-api-secret"),
+              help="Your FTX API secret")
+@click.option("--ftx-account-tier",
+              type=str,
+              default=lambda: _get_default_value("ftx-account-tier"),
+              help="Your FTX Account Tier")
+@click.option("--ftx-exchange-name",
+              type=str,
+              help="FTX exchange name [FTX, FTXUS]")
 @click.option("--release",
               is_flag=True,
               default=False,
@@ -561,20 +637,28 @@ def live(project: Path,
          gdax_api_secret: Optional[str],
          gdax_passphrase: Optional[str],
          gdax_use_sandbox: Optional[bool],
+         binance_organization: Optional[str],
          binance_api_key: Optional[str],
          binance_api_secret: Optional[str],
          binance_use_testnet: Optional[bool],
+         zerodha_organization: Optional[str],
          zerodha_api_key: Optional[str],
          zerodha_access_token: Optional[str],
          zerodha_product_type: Optional[str],
          zerodha_trading_segment: Optional[str],
          zerodha_history_subscription: Optional[bool],
+         samco_organization: Optional[str],
+         samco_client_id: Optional[str],
+         samco_client_password: Optional[str],
+         samco_year_of_birth: Optional[str],
+         samco_product_type: Optional[str],
+         samco_trading_segment: Optional[str],
          iqfeed_iqconnect: Optional[Path],
          iqfeed_username: Optional[str],
          iqfeed_password: Optional[str],
          iqfeed_product_name: Optional[str],
          iqfeed_version: Optional[str],
-         bloomberg_organization: Optional[str],
+         terminal_link_organization: Optional[str],
          bloomberg_environment: Optional[str],
          bloomberg_server_host: Optional[str],
          bloomberg_server_port: Optional[int],
@@ -611,6 +695,15 @@ def live(project: Path,
          tt_order_routing_host: Optional[str],
          tt_order_routing_port: Optional[str],
          tt_log_fix_messages: Optional[bool],
+         kraken_organization: Optional[str],
+         kraken_api_key: Optional[str],
+         kraken_api_secret: Optional[str],
+         kraken_verification_tier: Optional[str],
+         ftx_organization: Optional[str],
+         ftx_api_key: Optional[str],
+         ftx_api_secret: Optional[str],
+         ftx_account_tier: Optional[str],
+         ftx_exchange_name: Optional[str],
          release: bool,
          image: Optional[str],
          update: bool) -> None:
@@ -688,34 +781,50 @@ def live(project: Path,
                                                         gdax_use_sandbox)
         elif brokerage == BinanceBrokerage.get_name():
             ensure_options(["binance_api_key", "binance_api_secret", "binance_use_testnet"])
-            brokerage_configurer = BinanceBrokerage(binance_api_key, binance_api_secret, binance_use_testnet)
+            brokerage_configurer = BinanceBrokerage(_get_organization_id(binance_organization, "Binance"), 
+                                                    binance_api_key, 
+                                                    binance_api_secret, 
+                                                    binance_use_testnet)
         elif brokerage == ZerodhaBrokerage.get_name():
             ensure_options(["zerodha_api_key",
                             "zerodha_access_token",
                             "zerodha_product_type",
                             "zerodha_trading_segment"])
-            brokerage_configurer = ZerodhaBrokerage(zerodha_api_key,
+            brokerage_configurer = ZerodhaBrokerage(_get_organization_id(zerodha_organization, "Zerodha"),
+                                                    zerodha_api_key,
                                                     zerodha_access_token,
                                                     zerodha_product_type,
                                                     zerodha_trading_segment)
-        elif brokerage == BloombergBrokerage.get_name():
+        elif brokerage == SamcoBrokerage.get_name():
+            ensure_options(["samco_client_id",
+                            "samco_client_password",
+                            "samco_year_of_birth",
+                            "samco_product_type",
+                            "samco_trading_segment"])
+            brokerage_configurer = SamcoBrokerage(_get_organization_id(samco_organization, "Samco"),
+                                                    samco_client_id,
+                                                    samco_client_password,
+                                                    samco_year_of_birth,
+                                                    samco_product_type,
+                                                    samco_trading_segment)
+        elif brokerage == TerminalLinkBrokerage.get_name():
             ensure_options(["bloomberg_environment",
                             "bloomberg_server_host",
                             "bloomberg_server_port",
                             "bloomberg_emsx_broker",
                             "bloomberg_allow_modification"])
-            brokerage_configurer = BloombergBrokerage(_get_organization_id(bloomberg_organization, "Bloomberg"),
-                                                      bloomberg_environment,
-                                                      bloomberg_server_host,
-                                                      bloomberg_server_port,
-                                                      bloomberg_symbol_map_file,
-                                                      bloomberg_emsx_broker,
-                                                      bloomberg_emsx_user_time_zone,
-                                                      bloomberg_emsx_account,
-                                                      bloomberg_emsx_strategy,
-                                                      bloomberg_emsx_notes,
-                                                      bloomberg_emsx_handling,
-                                                      bloomberg_allow_modification)
+            brokerage_configurer = TerminalLinkBrokerage(_get_organization_id(terminal_link_organization, "Terminal Link"),
+                                                         bloomberg_environment,
+                                                         bloomberg_server_host,
+                                                         bloomberg_server_port,
+                                                         bloomberg_symbol_map_file,
+                                                         bloomberg_emsx_broker,
+                                                         bloomberg_emsx_user_time_zone,
+                                                         bloomberg_emsx_account,
+                                                         bloomberg_emsx_strategy,
+                                                         bloomberg_emsx_notes,
+                                                         bloomberg_emsx_handling,
+                                                         bloomberg_allow_modification)
         elif brokerage == AtreyuBrokerage.get_name():
             ensure_options(["atreyu_host",
                             "atreyu_req_port",
@@ -767,6 +876,19 @@ def live(project: Path,
                                                                 tt_order_routing_host,
                                                                 tt_order_routing_port,
                                                                 tt_log_fix_messages)
+        elif brokerage == KrakenBrokerage.get_name():
+            ensure_options(["kraken_api_key", "kraken_api_secret", "kraken_verification_tier"])
+            brokerage_configurer = KrakenBrokerage(_get_organization_id(kraken_organization, "Kraken"),
+                                                   kraken_api_key,
+                                                   kraken_api_secret,
+                                                   kraken_verification_tier)
+        elif brokerage == FTXBrokerage.get_name():
+            ensure_options(["ftx_api_key", "ftx_api_secret", "ftx_account_tier", "ftx_exchange_name"])
+            brokerage_configurer = FTXBrokerage(_get_organization_id(ftx_organization, "FTX"),
+                                                ftx_api_key,
+                                                ftx_api_secret,
+                                                ftx_account_tier,
+                                                ftx_exchange_name)
 
         if data_feed == InteractiveBrokersDataFeed.get_name():
             ensure_options(["ib_user_name", "ib_account", "ib_password", "ib_enable_delayed_streaming_data"])
@@ -795,7 +917,8 @@ def live(project: Path,
                                                                             gdax_use_sandbox))
         elif data_feed == BinanceDataFeed.get_name():
             ensure_options(["binance_api_key", "binance_api_secret", "binance_use_testnet"])
-            data_feed_configurer = BinanceDataFeed(BinanceBrokerage(binance_api_key,
+            data_feed_configurer = BinanceDataFeed(BinanceBrokerage(_get_organization_id(binance_organization, "Binance"),
+                                                                    binance_api_key,
                                                                     binance_api_secret,
                                                                     binance_use_testnet))
         elif data_feed == ZerodhaDataFeed.get_name():
@@ -804,30 +927,43 @@ def live(project: Path,
                             "zerodha_product_type",
                             "zerodha_trading_segment",
                             "zerodha_history_subscription"])
-            data_feed_configurer = ZerodhaDataFeed(ZerodhaBrokerage(zerodha_api_key,
+            data_feed_configurer = ZerodhaDataFeed(ZerodhaBrokerage(_get_organization_id(zerodha_organization, "Zerodha"),
+                                                                    zerodha_api_key,
                                                                     zerodha_access_token,
                                                                     zerodha_product_type,
                                                                     zerodha_trading_segment),
                                                    zerodha_history_subscription)
-        elif data_feed == BloombergDataFeed.get_name():
+        elif data_feed == SamcoDataFeed.get_name():
+            ensure_options(["samco_client_id",
+                            "samco_client_password",
+                            "samco_year_of_birth",
+                            "samco_product_type",
+                            "samco_trading_segment"])
+            data_feed_configurer = SamcoDataFeed(SamcoBrokerage(_get_organization_id(samco_organization, "Samco"),
+                                                    samco_client_id,
+                                                    samco_client_password,
+                                                    samco_year_of_birth,
+                                                    samco_product_type,
+                                                    samco_trading_segment))
+        elif data_feed == TerminalLinkDataFeed.get_name():
             ensure_options(["bloomberg_environment",
                             "bloomberg_server_host",
                             "bloomberg_server_port",
                             "bloomberg_emsx_broker",
                             "bloomberg_allow_modification"])
-            data_feed_configurer = BloombergDataFeed(BloombergBrokerage(_get_organization_id(bloomberg_organization,
-                                                                                             "Bloomberg"),
-                                                                        bloomberg_environment,
-                                                                        bloomberg_server_host,
-                                                                        bloomberg_server_port,
-                                                                        bloomberg_symbol_map_file,
-                                                                        bloomberg_emsx_broker,
-                                                                        bloomberg_emsx_user_time_zone,
-                                                                        bloomberg_emsx_account,
-                                                                        bloomberg_emsx_strategy,
-                                                                        bloomberg_emsx_notes,
-                                                                        bloomberg_emsx_handling,
-                                                                        bloomberg_allow_modification))
+            data_feed_configurer = TerminalLinkDataFeed(TerminalLinkBrokerage(_get_organization_id(terminal_link_organization,
+                                                                                             "Terminal Link"),
+                                                                           bloomberg_environment,
+                                                                           bloomberg_server_host,
+                                                                           bloomberg_server_port,
+                                                                           bloomberg_symbol_map_file,
+                                                                           bloomberg_emsx_broker,
+                                                                           bloomberg_emsx_user_time_zone,
+                                                                           bloomberg_emsx_account,
+                                                                           bloomberg_emsx_strategy,
+                                                                           bloomberg_emsx_notes,
+                                                                           bloomberg_emsx_handling,
+                                                                           bloomberg_allow_modification))
         elif data_feed == TradingTechnologiesDataFeed.get_name():
             ensure_options(["tt_user_name",
                             "tt_session_password",
@@ -872,6 +1008,21 @@ def live(project: Path,
                                                   iqfeed_password,
                                                   iqfeed_product_name,
                                                   iqfeed_version)
+        elif data_feed == KrakenDataFeed.get_name():
+            ensure_options(["kraken_api_key", "kraken_api_secret", "kraken_verification_tier"])
+            data_feed_configurer = KrakenDataFeed(
+                KrakenBrokerage(_get_organization_id(kraken_organization, "Kraken"),
+                                kraken_api_key,
+                                kraken_api_secret,
+                                kraken_verification_tier))
+        elif data_feed == FTXDataFeed.get_name():
+            ensure_options(["ftx_api_key", "ftx_api_secret", "ftx_account_tier", "ftx_echange_name"])
+            data_feed_configurer = FTXDataFeed(
+                FTXBrokerage(_get_organization_id(ftx_organization, "FTX"),
+                             ftx_api_key,
+                             ftx_api_secret,
+                             ftx_account_tier,
+                             ftx_exchange_name))
 
         environment_name = "lean-cli"
         lean_config = lean_config_manager.get_complete_lean_config(environment_name, algorithm_file, None)
