@@ -34,7 +34,7 @@ from lean.models.optimizer import OptimizationTarget
 @click.option("--output",
               type=PathParameter(exists=False, file_okay=False, dir_okay=True),
               help="Directory to store results in (defaults to PROJECT/optimizations/TIMESTAMP)")
-@click.option("--detach",
+@click.option("--detach", "-d",
               is_flag=True,
               default=False,
               help="Run the optimization in a detached Docker container and return immediately")
@@ -177,8 +177,11 @@ def optimize(project: Path,
     with config_path.open("w+", encoding="utf-8") as file:
         file.write(json.dumps(config, indent=4) + "\n")
 
+    project_config_manager = container.project_config_manager()
     cli_config_manager = container.cli_config_manager()
-    engine_image = cli_config_manager.get_engine_image(image)
+
+    project_config = project_config_manager.get_project_config(algorithm_file.parent)
+    engine_image = cli_config_manager.get_engine_image(image or project_config.get("engine-image", None))
 
     lean_config_manager = container.lean_config_manager()
     lean_config = lean_config_manager.get_complete_lean_config("backtesting", algorithm_file, None)
@@ -202,14 +205,11 @@ def optimize(project: Path,
               read_only=True)
     )
 
-    docker_manager = container.docker_manager()
-
-    if update or not docker_manager.supports_dotnet_5(engine_image):
-        docker_manager.pull_image(engine_image)
+    container.update_manager().pull_docker_image_if_necessary(engine_image, update)
 
     project_manager.copy_code(algorithm_file.parent, output / "code")
 
-    success = docker_manager.run_image(engine_image, **run_options)
+    success = container.docker_manager().run_image(engine_image, **run_options)
 
     logger = container.logger()
     cli_root_dir = container.lean_config_manager().get_cli_root_directory()
@@ -250,7 +250,3 @@ def optimize(project: Path,
     else:
         raise RuntimeError(
             f"Something went wrong while running the optimization, the output is stored in '{relative_output_dir}'")
-
-    if str(engine_image) == DEFAULT_ENGINE_IMAGE and not update:
-        update_manager = container.update_manager()
-        update_manager.warn_if_docker_image_outdated(engine_image)
