@@ -12,7 +12,9 @@
 # limitations under the License.
 
 import multiprocessing
+import tarfile
 from pathlib import Path
+from datetime import *
 from typing import Any, List, Callable
 
 from joblib import delayed, Parallel
@@ -20,7 +22,13 @@ from joblib import delayed, Parallel
 from lean.components.api.api_client import APIClient
 from lean.components.config.lean_config_manager import LeanConfigManager
 from lean.components.util.logger import Logger
-from lean.models.errors import RequestFailedError
+from lean.models.errors import MoreInfoError, RequestFailedError
+
+
+def _store_local_file(file_content: bytes, file_path: Path):
+    file_path.parent.mkdir(parents=True, exist_ok=True)
+    with file_path.open("wb+") as f:
+        f.write(file_content)
 
 
 class DataDownloader:
@@ -37,6 +45,33 @@ class DataDownloader:
         self._api_client = api_client
         self._lean_config_manager = lean_config_manager
 
+    def update_database_files(self):
+        """Will update lean data folder database files if required
+
+        """
+        try:
+            now = datetime.now()
+            config = self._lean_config_manager.get_lean_config()
+            last_update = config["file-database-last-update"] if "file-database-last-update" in config else ''
+            if not last_update or now - datetime.strptime(last_update, '%m/%d/%Y') > timedelta(days=1):
+                data_dir = self._lean_config_manager.get_data_directory()
+
+                _store_local_file(self._api_client.data.download_public_file(
+                    "https://raw.githubusercontent.com/QuantConnect/Lean/master/Data/symbol-properties/symbol-properties-database.csv"),
+                    data_dir / "symbol-properties" / "symbol-properties-database.csv")
+                _store_local_file(self._api_client.data.download_public_file(
+                    "https://raw.githubusercontent.com/QuantConnect/Lean/master/Data/market-hours/market-hours-database.json"),
+                    data_dir / "market-hours" / "market-hours-database.json")
+
+                self._lean_config_manager.set_properties({"file-database-last-update": now.strftime('%m/%d/%Y')})
+        except MoreInfoError as e:
+            if "not found" in str(e):
+                pass
+            else:
+                self._logger.error(str(e))
+        except Exception as e:
+            self._logger.error(str(e))
+
     def download_files(self, data_files: List[Any], overwrite: bool, organization_id: str) -> None:
         """Downloads files from QuantConnect Datasets to the local data directory.
 
@@ -52,20 +87,37 @@ class DataDownloader:
 
             data_dir = self._lean_config_manager.get_data_directory()
             parallel(delayed(self._download_file)(data_file.file, overwrite, data_dir, organization_id,
-                                                  lambda: progress.update(progress_task, advance=1))
+                                                  lambda advance: progress.update(progress_task, advance=advance))
                      for data_file in data_files)
 
+            # update our config after we download all files, and not in parallel!
+            for relative_file in data_files:
+                if "/map_files/map_files_" in relative_file and relative_file.endswith(".zip"):
+                    self._lean_config_manager.set_properties({
+                        "map-file-provider": "QuantConnect.Data.Auxiliary.LocalZipMapFileProvider"
+                    })
+                if "/factor_files/factor_files_" in relative_file and relative_file.endswith(".zip"):
+                    self._lean_config_manager.set_properties({
+                        "factor-file-provider": "QuantConnect.Data.Auxiliary.LocalZipFactorFileProvider"
+                    })
+
             progress.stop()
         except KeyboardInterrupt as e:
             progress.stop()
             raise e
 
+    def _process_bulk(self, file: Path, destination: Path):
+        tar = tarfile.open(file)
+        tar.errorlevel = 0
+        tar.extractall(destination)
+        tar.close()
+
     def _download_file(self,
                        relative_file: str,
                        overwrite: bool,
                        data_directory: Path,
                        organization_id: str,
-                       callback: Callable[[], None]) -> None:
+                       progress_callback: Callable[[float], None]) -> None:
         """Downloads a single file from QuantConnect Datasets to the local data directory.
 
         If this method downloads a map or factor files zip file,
@@ -84,28 +136,16 @@ class DataDownloader:
                 f"{local_path} already exists, use --overwrite to overwrite it",
                 "You have not been charged for this file"
             ]))
-            callback()
+            progress_callback(1)
             return
 
         try:
-            file_content = self._api_client.data.download_file(relative_file, organization_id)
+            self._api_client.data.download_file(relative_file, organization_id, local_path, progress_callback)
         except RequestFailedError as error:
             self._logger.warn(f"{local_path}: {error}\nYou have not been charged for this file")
-            callback()
+            progress_callback(1)
             return
 
-        local_path.parent.mkdir(parents=True, exist_ok=True)
-        with local_path.open("wb+") as f:
-            f.write(file_content)
-
-        if relative_file.startswith("equity/usa/map_files/map_files_") and relative_file.endswith(".zip"):
-            self._lean_config_manager.set_properties({
-                "map-file-provider": "QuantConnect.Data.Auxiliary.LocalZipMapFileProvider"
-            })
-
-        if relative_file.startswith("equity/usa/factor_files/factor_files_") and relative_file.endswith(".zip"):
-            self._lean_config_manager.set_properties({
-                "factor-file-provider": "QuantConnect.Data.Auxiliary.LocalZipFactorFileProvider"
-            })
-
-        callback()
+        # Special case: bulk files need unpacked
+        if "setup/" in relative_file and relative_file.endswith(".tar"):
+            self._process_bulk(local_path, data_directory)
