@@ -18,6 +18,10 @@ from lean.models.brokerages.cloud.interactive_brokers import InteractiveBrokersB
 from lean.models.brokerages.cloud.oanda import OANDABrokerage
 from lean.models.brokerages.cloud.paper_trading import PaperTradingBrokerage
 from lean.models.brokerages.cloud.tradier import TradierBrokerage
+from lean.models.brokerages.cloud.kraken import KrakenBrokerage
+from lean.models.brokerages.cloud.ftx import FTXBrokerage
+from lean.models.brokerages.cloud.zerodha import ZerodhaBrokerage
+from lean.models.brokerages.cloud.samco import SamcoBrokerage
 
 all_cloud_brokerages = [
     PaperTradingBrokerage,
@@ -26,5 +30,9 @@ all_cloud_brokerages = [
     OANDABrokerage,
     BitfinexBrokerage,
     CoinbaseProBrokerage,
-    BinanceBrokerage
+    BinanceBrokerage,
+    KrakenBrokerage,
+    FTXBrokerage,
+    ZerodhaBrokerage,
+    SamcoBrokerage,
 ]
