@@ -18,12 +18,17 @@ import click
 from lean.components.util.logger import Logger
 from lean.models.brokerages.local.base import LocalBrokerage
 from lean.models.config import LeanConfigConfigurer
-
+from lean.container import container
+from lean.constants import ZERODHA_PRODUCT_ID
+from lean.models.logger import Option
 
 class ZerodhaBrokerage(LocalBrokerage):
     """A LocalBrokerage implementation for the Zerodha brokerage."""
 
-    def __init__(self, api_key: str, access_token: str, product_type: str, trading_segment: str) -> None:
+    _is_module_installed = False
+
+    def __init__(self, organization_id: str, api_key: str, access_token: str, product_type: str, trading_segment: str) -> None:
+        self._organization_id = organization_id
         self._api_key = api_key
         self._access_token = access_token
         self._product_type = product_type
@@ -33,8 +38,23 @@ class ZerodhaBrokerage(LocalBrokerage):
     def get_name(cls) -> str:
         return "Zerodha"
 
+    @classmethod
+    def get_module_id(cls) -> int:
+        return ZERODHA_PRODUCT_ID
+
     @classmethod
     def _build(cls, lean_config: Dict[str, Any], logger: Logger) -> LocalBrokerage:
+        
+        api_client = container.api_client()
+
+        organizations = api_client.organizations.get_all()
+        options = [Option(id=organization.id, label=organization.name) for organization in organizations]
+
+        organization_id = logger.prompt_list(
+            "Select the organization with the Zerodha module subscription",
+            options
+        )
+
         logger.info("You need API credentials for Kite Connect (https://kite.trade/) to use the Zerodha brokerage.")
 
         api_key = click.prompt("API key", cls._get_default(lean_config, "zerodha-api-key"))
@@ -60,24 +80,32 @@ The trading segment must be set to EQUITY if you are trading equities on NSE or
             type=click.Choice(["EQUITY", "COMMODITY"], case_sensitive=False)
         )
 
-        return ZerodhaBrokerage(api_key, access_token, product_type, trading_segment)
+        return ZerodhaBrokerage(organization_id, api_key, access_token, product_type, trading_segment)
 
     def _configure_environment(self, lean_config: Dict[str, Any], environment_name: str) -> None:
+        self.ensure_module_installed()
         lean_config["environments"][environment_name]["live-mode-brokerage"] = "ZerodhaBrokerage"
         lean_config["environments"][environment_name]["transaction-handler"] = \
             "QuantConnect.Lean.Engine.TransactionHandlers.BrokerageTransactionHandler"
 
     def configure_credentials(self, lean_config: Dict[str, Any]) -> None:
+        lean_config["job-organization-id"] = self._organization_id
         lean_config["zerodha-api-key"] = self._api_key
         lean_config["zerodha-access-token"] = self._access_token
         lean_config["zerodha-product-type"] = self._product_type
         lean_config["zerodha-trading-segment"] = self._trading_segment
 
-        self._save_properties(lean_config, ["zerodha-api-key",
+        self._save_properties(lean_config, ["job-organization-id",
+                                            "zerodha-api-key",
                                             "zerodha-access-token",
                                             "zerodha-product-type",
                                             "zerodha-trading-segment"])
 
+    def ensure_module_installed(self) -> None:
+        if not self._is_module_installed:
+            container.module_manager().install_module(self.__class__.get_module_id(), self._organization_id)
+            self._is_module_installed = True
+
 
 class ZerodhaDataFeed(LeanConfigConfigurer):
     """A LeanConfigConfigurer implementation for the Zerodha data feed."""
@@ -102,6 +130,7 @@ class ZerodhaDataFeed(LeanConfigConfigurer):
         return ZerodhaDataFeed(brokerage, history_subscription)
 
     def configure(self, lean_config: Dict[str, Any], environment_name: str) -> None:
+        self._brokerage.ensure_module_installed()
         lean_config["environments"][environment_name]["data-queue-handler"] = "ZerodhaBrokerage"
         lean_config["environments"][environment_name]["history-provider"] = "BrokerageHistoryProvider"
 
